@@ -1,32 +1,29 @@
-/*
- *  bfb/bfb.c: BFB transport encapsulation (used for Siemens mobile equipment)
- *
- *  Copyright (c) 2002 Christian W. Zuckschwerdt <zany@triq.net>
- *
- *  This program is free software; you can redistribute it and/or modify it
- *  under the terms of the GNU General Public License as published by the Free
- *  Software Foundation; either version 2 of the License, or (at your option)
- *  any later version.
- *
- *  This program is distributed in the hope that it will be useful, but
- *  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- *  for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *     
- */
-/*
- *  v0.1:  Die,  5 Feb 2002 22:46:19 +0100
- *  v0.4:  Don, 25 Jul 2002 03:16:41 +0200
+/**
+	\file bfb/bfb.c
+	BFB transport encapsulation (used for Siemens mobile equipment).
+	ObexFTP library - language bindings for OBEX file transfer.
+
+	Copyright (c) 2002-2007 Christian W. Zuckschwerdt <zany@triq.net>
+
+	ObexFTP is free software; you can redistribute it and/or modify
+	it under the terms of the GNU Lesser General Public License as
+	published by the Free Software Foundation; either version 2 of
+	the License, or (at your option) any later version.
+
+	This program is distributed in the hope that it will be useful,
+	but WITHOUT ANY WARRANTY; without even the implied warranty of
+	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+	GNU Lesser General Public License for more details.
+
+	You should have received a copy of the GNU Lesser General Public
+	License along with ObexFTP. If not, see <http://www.gnu.org/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <stdio.h>
 #include <stdlib.h>
 #include <inttypes.h>
 #include <string.h>
@@ -38,7 +35,8 @@
 
 /* htons */
 #ifdef _WIN32
-#include <winsock.h>
+#include <winsock2.h>
+#include <sys/param.h> /* for endianess */
 #else
 #include <netinet/in.h>
 #endif
@@ -84,7 +82,10 @@
 
 #endif
 
-/* returns the whole buffer folded with xor. */
+
+/**
+	Returns the whole buffer folded with xor.
+ */
 uint8_t bfb_checksum(uint8_t *data, int len)
 {
 	int i;
@@ -96,12 +97,15 @@ uint8_t bfb_checksum(uint8_t *data, int len)
 	return chk;
 }
 
-/* stuff data frame into serial cable encapsulation */
-/* buffer needs to be of at leaset len+7 size */
-/* Type 0x01: "prepare" command. */
-/* Type 0x02: first transmission in a row. */
-/* Type 0x03: continued transmission. */
-/* seq needs to be incremented afterwards. */
+
+/**
+	Stuff data frame into serial cable encapsulation.
+	buffer needs to be of at leaset len+7 size
+	Type 0x01: "prepare" command.
+	Type 0x02: first transmission in a row.
+	Type 0x03: continued transmission.
+	seq needs to be incremented afterwards.
+ */
 int bfb_stuff_data(uint8_t *buffer, uint8_t type, uint8_t *data, uint16_t len, uint8_t seq)
 {
         int i;
@@ -151,7 +155,10 @@ int bfb_stuff_data(uint8_t *buffer, uint8_t type, uint8_t *data, uint16_t len, u
 	return len+7;
 }
 
-/* send a cmd, subcmd packet, add chk (no parameters) */
+
+/**
+	Send a cmd, subcmd packet, add chk (no parameters).
+ */
 int bfb_write_subcmd(fd_t fd, uint8_t type, uint8_t subtype)
 {
 	uint8_t buffer[2];
@@ -162,13 +169,19 @@ int bfb_write_subcmd(fd_t fd, uint8_t type, uint8_t subtype)
 	return bfb_write_packets(fd, type, buffer, 2);
 }
 
-/* send a cmd, subcmd packet */
+
+/**
+	Send a cmd, subcmd packet.
+ */
 int bfb_write_subcmd0(fd_t fd, uint8_t type, uint8_t subtype)
 {
 	return bfb_write_packets(fd, type, &subtype, 1);
 }
 
-/* send a cmd, subcmd, data packet */
+
+/**
+	Send a cmd, subcmd, data packet.
+ */
 int bfb_write_subcmd8(fd_t fd, uint8_t type, uint8_t subtype, uint8_t p1)
 {
 	uint8_t buffer[2];
@@ -179,7 +192,10 @@ int bfb_write_subcmd8(fd_t fd, uint8_t type, uint8_t subtype, uint8_t p1)
 	return bfb_write_packets(fd, type, buffer, 2);
 }
 
-/* send a cmd, subcmd packet, add chk (one word parameter) */
+
+/**
+	Send a cmd, subcmd packet, add chk (one word parameter).
+ */
 int bfb_write_subcmd1(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1)
 {
 	uint8_t buffer[4];
@@ -197,7 +213,10 @@ int bfb_write_subcmd1(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1)
 	return bfb_write_packets(fd, type, buffer, 4);
 }
 
-/* send a cmd, subcmd packet, add chk (two word parameter) */
+
+/**
+	Send a cmd, subcmd packet, add chk (two word parameter).
+ */
 int bfb_write_subcmd2(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1, uint16_t p2)
 {
 	uint8_t buffer[6];
@@ -219,7 +238,10 @@ int bfb_write_subcmd2(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1, uint1
 	return bfb_write_packets(fd, type, buffer, 6);
 }
 
-/* send a cmd, subcmd packet, add chk (three word parameter) */
+
+/**
+	Send a cmd, subcmd packet, add chk (three word parameter).
+ */
 int bfb_write_subcmd3(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1, uint16_t p2, uint16_t p3)
 {
 	uint8_t buffer[8];
@@ -244,7 +266,10 @@ int bfb_write_subcmd3(fd_t fd, uint8_t type, uint8_t subtype, uint16_t p1, uint1
 	return bfb_write_packets(fd, type, buffer, 8);
 }
 
-/* send a cmd, subcmd packet, add long, word parameter */
+
+/**
+	Send a cmd, subcmd packet, add long, word parameter.
+ */
 int bfb_write_subcmd_lw(fd_t fd, uint8_t type, uint8_t subtype, uint32_t p1, uint16_t p2)
 {
 	uint8_t buffer[8];
@@ -269,8 +294,10 @@ int bfb_write_subcmd_lw(fd_t fd, uint8_t type, uint8_t subtype, uint32_t p1, uin
 }
 
 
-/* send actual packets */
-/* patch from Jorge Ventura to handle EAGAIN from write */
+/**
+	Send actual packets.
+	Patch from Jorge Ventura to handle EAGAIN from write.
+ */
 int bfb_write_packets(fd_t fd, uint8_t type, uint8_t *buffer, int length)
 {
 	bfb_frame_t *frame;
@@ -345,6 +372,10 @@ int bfb_write_packets(fd_t fd, uint8_t type, uint8_t *buffer, int length)
 	return i / MAX_PACKET_DATA;
 }
 
+
+/**
+	Stuff data into packet buffers and send all packets.
+ */
 int bfb_send_data(fd_t fd, uint8_t type, uint8_t *data, uint16_t length, uint8_t seq)
 {
 	uint8_t *buffer;
@@ -366,7 +397,9 @@ int bfb_send_data(fd_t fd, uint8_t type, uint8_t *data, uint16_t length, uint8_t
 }
 
 
-/* retrieve actual packets */
+/**
+	Retrieve actual packets.
+ */
 /*@null@*/
 bfb_frame_t *bfb_read_packets(uint8_t *buffer, int *length)
 {
@@ -420,6 +453,10 @@ bfb_frame_t *bfb_read_packets(uint8_t *buffer, int *length)
 	return frame;
 }
 
+
+/**
+	Append BFB frame to a data buffer.
+ */
 int	bfb_assemble_data(bfb_data_t **data, int *size, int *len, bfb_frame_t *frame)
 {
 	bfb_data_t *tmp;
@@ -456,6 +493,10 @@ int	bfb_assemble_data(bfb_data_t **data, int *size, int *len, bfb_frame_t *frame
 	return 1;
 }
 
+
+/**
+	Check if data buffer is complete and valid.
+ */
 int bfb_check_data(bfb_data_t *data, int len)
 {
 	int i;
